###########
 setux repl
###########

**Setux REPL**

========
Abstract
========

Rudimentary REPL for Setux

=====
Usage
=====

.. code-block:: shell

    setux


============
Installation
============

see the Setux package.
